__title__ = 'easys-ordermanager'
__description__ = 'API definition of RH order manager for EasyS'
__version__ = '1.4.32'
__url__ = 'https://github.com/RegioHelden/easys-ordermanager'
__author__ = 'Jens Nistler, Mounir Messelmeni'
__author_email__ = 'opensource@regiohelden.de'
__license__ = 'GPL 3'
